// BtAcquire.java
// Remote measuring device. Data transfered to a PC client.
// This is a Bluetooth server waiting for a connecting client.
// When the PC client disconnects, the server should wait for the
// next client to connect.
// For a demo, run NxtAcquire.java from the NxtJLib distribution

import ch.aplu.bluetooth.*;
import ch.aplu.nxt.*;
import lejos.nxt.Button;
import lejos.nxt.LCD;
import java.io.*;

public class BtAcquire implements BtListener
{
  private final boolean isNxtClient = false;  // true, if client is a NXT brick
  private NxtRobot robot = new NxtRobot();
  private LightSensor ls = new LightSensor(SensorPort.S3);
  private BluetoothServer bs;

  public BtAcquire()
  {
    robot.addPart(ls);
    LCD.drawString("Server started", 0, 0);
    LCD.drawString("Waiting...", 0, 1);
    LCD.drawString("Press ESCAPE", 0, 5);
    bs = new BluetoothServer(this, isNxtClient);
    while (!Button.ESCAPE.isPressed()) {}
    bs.cancel();
    robot.exit();
  }

  public void notifyConnection(InputStream is, OutputStream os)
  {
    LCD.drawString("Connection OK", 0, 1);
    DataInputStream dis = new DataInputStream(is);
    DataOutputStream dos = new DataOutputStream(os);
    robot.playTone(600, 100);
    Tools.delay(100);
    robot.playTone(1000, 100);

    while (true)
    {
      try
      {
        dis.readInt();   // Wait for request
      }
      catch (Exception ex)
      {
        if (!bs.isCanceled())
        {
          // Client disconnected, wait for next connect
          LCD.clear();
          LCD.drawString("Disconnected", 0, 0);
          LCD.drawString("Waiting", 0, 1);
          LCD.drawString("Press ESCAPE", 0, 5);
          robot.playTone(1000, 100);
          Tools.delay(100);
          robot.playTone(600, 100);
        }
        break; // Quit while loop
      }

      try
      {
        int value = ls.getValue();
        dos.writeInt(value);
        dos.flush();
        LCD.drawString("Lux: " + value,  0, 2);
      }
      catch (IOException ex)
      {}
    }
  }

  public static void main(String[] args)
  {
    new BtAcquire();
  }
}