// BtCar.java
// Demo how to use class Transmitter
// Receives commands from BTControl

import ch.aplu.nxt.*;
import lejos.nxt.Button;
import lejos.nxt.ButtonListener;

public class BtCar implements TransceiverListener, ButtonListener
{
  private NxtRobot robot = new NxtRobot();
  private Transceiver tr = new Transceiver("APLU1");
  private Gear gear = new Gear();

  public BtCar()
  {
    Button.ESCAPE.addButtonListener(this);
    robot.addPart(gear);
    gear.setSpeed(25);
    robot.addPart(tr);
    tr.addTransceiverListener(this);

    System.out.println("Try conn APLU1..");
    tr.switchOn(false);  // Blocks until connected or canceled
    if (tr.isConnected())
      Tools.putSleep();
    robot.exit();
  }

  public void received(int state, int value)
  {
    System.out.println("s:" + state + " v:" + value);
    if (state == 0)
    {
      robot.playTone(1000, 100);
      gear.forward();
    }
    if (state == 1)
    {
      robot.playTone(2000, 100);
      gear.backward();
    }
  }

  public void notifyConnection(boolean connected)
  {
    if (connected)
    {
      playConn();
      System.out.println("Connected");
    }
    else
    {
      playDisconn();
      System.out.println("Disconnected");
      Tools.wakeUp();
    }
  }

  public void isListening()
  {
    playListening();
    System.out.println("Conn failed.");
    System.out.println("Listening..");
  }


  public void buttonPressed(Button b)
  {
    tr.releaseConnection();
    Tools.wakeUp();
  }

  public void buttonReleased(Button b)
  {
  }

  private void playConn()
  {
    robot.playTone(400, 200);
    Tools.delay(200);
    robot.playTone(600, 200);
    Tools.delay(200);
  }

  private void playDisconn()
  {
    robot.playTone(600, 200);
    Tools.delay(200);
    robot.playTone(400, 200);
    Tools.delay(200);
  }

  private void playListening()
  {
    for (int i = 0; i < 3; i++)
    {
      robot.playTone(3000, 50);
      Tools.delay(100);
    }
  }

  public static void main(String[] args)
  {
    new BtCar();
  }
}