// BtControl.java
// Demo how to use class Transmitter
// Controls BtCar via Bluetooth

import ch.aplu.nxt.*;
import lejos.nxt.Button;
import lejos.nxt.ButtonListener;

public class BtControl implements TouchListener, TransceiverListener, ButtonListener
{
  private NxtRobot robot = new NxtRobot();
  private Transceiver tr = new Transceiver("NXT");
  private boolean isCanceled = false;

  public BtControl()
  {
    Button.ESCAPE.addButtonListener(this);
    robot.addPart(tr);
    tr.addTransceiverListener(this);

    TouchSensor ts1 = new TouchSensor(SensorPort.S1);
    robot.addPart(ts1);
    ts1.addTouchListener(this);

    System.out.println("Try conn NXT..");
    tr.switchOn(false);  // Blocks until connected or canceled
    if (tr.isConnected())
      Tools.putSleep();
    robot.exit();
  }

  public void pressed(SensorPort port)
  {
    tr.send(1, 0);
  }

  public void released(SensorPort port)
  {
    tr.send(0, 0);
  }

  public void received(int state, int value)
  {
  }

  public void notifyConnection(boolean connected)
  {
    if (connected)
    {
      playConn();
      System.out.println("Connected");
    }
    else
    {
      playDisconn();
      System.out.println("Disconnected");
      Tools.wakeUp();
    }
  }

  public void isListening()
  {
    playListening();
    System.out.println("Conn failed.");
    System.out.println("Listening..");
  }

  public void buttonPressed(Button b)
  {
    tr.releaseConnection();
    Tools.wakeUp();
  }

  public void buttonReleased(Button b)
  {
  }

  private void playConn()
  {
    robot.playTone(400, 200);
    Tools.delay(200);
    robot.playTone(600, 200);
    Tools.delay(200);
  }

  private void playDisconn()
  {
    robot.playTone(600, 200);
    Tools.delay(200);
    robot.playTone(400, 200);
    Tools.delay(200);
  }

  private void playListening()
  {
    for (int i = 0; i < 3; i++)
    {
      robot.playTone(3000, 50);
      Tools.delay(100);
    }
  }

  public static void main(String[] args)
  {
    new BtControl();
  }
}