// BtPeerInq.java
// Inquiry Machine, use BtPeerAns as 'Answer Machine'
// Be sure, that the partner's node is added to the NXT Bluetooth devices

import ch.aplu.nxt.*;
import ch.aplu.bluetooth.*;
import java.util.*;
import lejos.nxt.*;

public class BtPeerInq
  implements BtPeerListener, ButtonListener
{
  private BluetoothPeer bp;
  private final String partnerName = "NXT";
  private volatile boolean isTerminating = false;

  public BtPeerInq()
  {
    System.out.println("Try connect " + partnerName);
    bp = new BluetoothPeer(partnerName, this);
    Button.ESCAPE.addButtonListener(this);
    if (bp.isConnected())
    {
      System.out.println("Connect OK");
      System.out.println("I am a client");
    }
    else
    {
      System.out.println("Connect failed");
      System.out.println("I am a server");
      System.out.println("Wait connect");
      Tools.putSleep();
    }
    if (!isTerminating)
      execute();
  }

  private void execute()
  {
    Random rnd = new Random();
    while (!isTerminating)
    {
      int size = 3;
      int[] data = new int[size];
      for (int i = 0; i < size; i++)
        data[i] = rnd.nextInt(10); // Random digit 0..9
      bp.sendDataBlock(data);
      System.out.println("Sent: " + toString(data));
      Tools.putSleep(); // Wait for reply
    }
  }

  public void receiveDataBlock(int[] data)
  {
    System.out.println("Rcvd: " + toString(data));
    Tools.wakeUp();
  }

  private String toString(int[] data)
  {
    StringBuffer sb = new StringBuffer();
    for (int i = 0; i < data.length; i++)
      sb.append(Integer.toString(data[i]));
    return sb.toString();
  }

  public void notifyConnection(boolean connected)
  {
    Tools.wakeUp();
    if (connected)
      System.out.println("Connection OK");
    else
    {
      isTerminating = true;
      bp.releaseConnection();
    }
  }

  public void buttonPressed(Button b)
  {
    if (b == Button.ESCAPE)
    {
      System.out.println("Terminating");
      isTerminating = true;
      Tools.wakeUp();
      bp.releaseConnection();
    }
  }

  public void buttonReleased(Button b)
  {}

  public static void main(String[] args)
  {
    new BtPeerInq(); // Verbose mode
  }
}


