// BtRemoteSensor.java

import ch.aplu.bluetooth.*;
import ch.aplu.nxt.*;
import lejos.nxt.Button;
import lejos.nxt.LCD;
import java.io.*;

public class BtRemoteSensor implements BtListener
{
  private final boolean isNxtClient = false;  // true, if client is a NXT brick
  private LightSensor ls = new LightSensor();
  private BluetoothServer bs;

  public BtRemoteSensor()
  {
    NxtRobot robot = new NxtRobot();
    robot.addPart(ls);
    LCD.drawString("Server started", 0, 0);
    LCD.drawString("Waiting...", 0, 1);
    LCD.drawString("Press ESCAPE", 0, 5);
    bs = new BluetoothServer(this, isNxtClient);
    while (!Button.ESCAPE.isPressed()) {}
    LCD.clear();
    LCD.drawString("Terminating", 0, 2);
    bs.cancel();
    robot.exit();
    Tools.delay(2000);
    // Program terminates
  }

  public void notifyConnection(InputStream is, OutputStream os)
  {
    LCD.drawString("Connection OK", 0, 1);
    DataInputStream dis = new DataInputStream(is);
    DataOutputStream dos = new DataOutputStream(os);

    while (true)
    {
      try
      {
        dis.readInt();   // Wait for request
      }
      catch (IOException ex)
      {
        if (!bs.isCanceled())
        {
          // Client disconnected, wait for next connect
          LCD.clear();
          LCD.drawString("Disconnected", 0, 0);
          LCD.drawString("Waiting", 0, 1);
          LCD.drawString("Press ESCAPE", 0, 5);
        }
        break; // Quit while loop
      }

      try
      {
        int value = ls.getValue();
        dos.writeInt(value);
        dos.flush();
        LCD.drawString("Lux: " + value,  0, 2);
      }
      catch (IOException ex)
      {}
    }
  }

  public static void main(String[] args)
  {
    new BtRemoteSensor();
  }
}
