// BtServer.java
// Exchange data with BtClient

import ch.aplu.bluetooth.*;
import ch.aplu.nxt.*;
import lejos.nxt.*;
import java.io.*;

public class BtServer implements BtListener
{
  private final boolean isNxtClient = false;  // true, if client is a NXT brick
  private BluetoothServer bs;

  public BtServer()
  {
    LCD.drawString("Server started", 0, 0);
    LCD.drawString("Waiting...", 0, 1);
    LCD.drawString("Press ESCAPE", 0, 5);
    bs = new BluetoothServer(this, isNxtClient);
    while (!Button.ESCAPE.isPressed()) {}
    LCD.clear();
    LCD.drawString("Terminating", 0, 2);
    bs.cancel(); // Terminates waiting server
    Tools.delay(2000);
    // Program terminates
  }

  public void notifyConnection(InputStream is, OutputStream os)
  {
    LCD.drawString("Connection OK", 0, 1);
    DataInputStream dis = new DataInputStream(is);
    DataOutputStream dos = new DataOutputStream(os);

    while (true)
    {
      int n = 0;
      try
      {
        n = dis.readInt();
      }
      catch (IOException ex)
      {
        if (!bs.isCanceled())
        {
          // Client disconnected, wait for next connect
          LCD.clear();
          LCD.drawString("Disconnected", 0, 0);
          LCD.drawString("Waiting", 0, 1);
          LCD.drawString("Press ESCAPE", 0, 5);
        }
        break; // Quit while loop
      }
      LCD.drawString("Got: " + n, 0, 2);

      try
      {
        dos.writeInt(-n);
        dos.flush();
      }
      catch (IOException ex)
      {
        // Should never happen
        LCD.clear();
        LCD.drawString("Write failed", 0, 0);
        LCD.drawString("Waiting...", 0, 1);
        LCD.drawString("Press ESCAPE", 0, 5);
        break;
      }
    }
  }

  public static void main(String[] args)
  {
    new BtServer();
  }
}
