// BtTrailer.java
// Example of Bluetooth data exchange using the Tranceiver class.
// A NXT rover (van) moves in front of another rover (trailer).
// The trailer uses a ultrasonic sensor to measure the distance.
// The trailer stops the van and repositions itself to realign with the van.
// Van program: BTVan.java

import ch.aplu.nxt.*;
import lejos.nxt.Button;
import lejos.nxt.LCD;

public class BtTrailer
{
  private interface Command
  {
    int GO   = 1;
    int STOP = 2;
  }

  private final String head = "NXT5";
  private final int period = 10; // ms
  private boolean wasLeft = false;

  public BtTrailer()
  {
    NxtRobot robot = new NxtRobot();

    Transceiver tr = new Transceiver(head);
    robot.addPart(tr);
    UltrasonicSensor us = new UltrasonicSensor();
    robot.addPart(us);

    Gear gear = new Gear();
    robot.addPart(gear);

    tr.switchOn();  // Blocks until connected

    tr.send(Command.GO, 0);
    gear.setSpeed(25);
    gear.forward();
    boolean isStopped = false;
    int n = 0;
    while (!Button.ESCAPE.isPressed())
    {
      int value = us.getDistance();
      LCD.clear();
      LCD.drawString("value: " + value, 0, 0);
      if (value > 30)  // 255 (distance fault): halt also
      {
        if (!isStopped)
        {
          isStopped = true;
          tr.send(Command.STOP, 0);  // Stop the van
          Tools.delay(1000);         // Approach the van
          turn(gear);                // Turn (left or right)
        }
        n++;
        if (n == 100)  // depends on period
          turn(gear);  // Van missed, turn in reverse dir
      }
      if (value < 25)
      {
        n = 0;
        if (isStopped)
        {
          isStopped = false;
          tr.send(Command.GO, 0);
          gear.setSpeed(25);
          gear.forward();
        }
      }
      Tools.delay(period); // To smooth the reaction
    }
    robot.exit();
  }

  private void turn(Gear gear)
  // Change turning direction each time
  {
    gear.setSpeed(5);
    if (wasLeft)
    {
      wasLeft = false;
      gear.right();
    }
    else
    {
      wasLeft = true;
      gear.left();
    }
  }


  public static void main(String[] args)
  {
    new BtTrailer();
  }
}
