// BtVan.java
// Example of Bluetooth data exchange using the Tranceiver class.
// A NXT rover (van) moves in front of another rover (trailer).
// The trailer uses a ultrasonic sensor to measure the distance.
// The trailer stops the van and repositions itself to realign with the van.
// Trailer program: BTTrailer.java

import ch.aplu.nxt.*;
import lejos.nxt.*;

public class BtVan
  implements TransceiverListener
{
  private interface Command
  {
    int GO    = 1;
    int STOP  = 2;
  }

  private final String trailer = "NXT";
  private Gear gear;
  private Transceiver tr;

  public BtVan()
  {
    NxtRobot robot = new NxtRobot();

    gear = new Gear();
    robot.addPart(gear);
    gear.setSpeed(30);

    tr = new Transceiver(trailer);
    tr.addTransceiverListener(this);
    robot.addPart(tr);

    tr.switchOn(); // Blocks until connected

    Tools.putSleep();  // Wait for termination
    robot.exit();
  }

  public void received(int state, int value)
  {
    System.out.println("command: " + state);
    switch (state)
    {
      case Command.GO:
        System.out.println("Go");
        gear.forward();
        break;

      case Command.STOP:
        System.out.println("Stop");
        gear.stop();
        break;
    }
  }

  public void notifyConnection(boolean connected)
  {
    if (!connected)
      Tools.wakeUp();  // Terminate program
  }

  public void isListening()
  {}

  public static void main(String[] args)
  {
    new BtVan();
  }
}
