// MultiSensor.java
// Several sensors, events

import ch.aplu.nxt.*;

public class MultiSensor
 implements TouchListener, LightListener, SoundListener
{
  private final int soundTriggerLevel = 30;
  private final int lightTriggerLevel = 400;
  private Gear gear;

  public MultiSensor()
  {
    NxtRobot robot = new NxtRobot();
    gear = new Gear();
    robot.addPart(gear);

    TouchSensor ts = new TouchSensor(SensorPort.S1);
    robot.addPart(ts);
    ts.addTouchListener(this);

    LightSensor ls = new LightSensor(SensorPort.S2);
    robot.addPart(ls);
    ls.addLightListener(this, lightTriggerLevel);

    SoundSensor ss = new SoundSensor(SensorPort.S3);
    robot.addPart(ss);
    ss.addSoundListener(this, soundTriggerLevel);

    Tools.waitEnter("ENTER to quit");
    robot.exit();
  }

  public void loud(SensorPort port, int level)
  {
    System.out.println("Evt: loud(" + level + ")");
  }

  public void quiet(SensorPort port, int level)
  {
    System.out.println("Evt: quiet(" + level + ")");
  }

  public void bright(SensorPort port, int level)
  {
    System.out.println("Evt: bright(" + level + ")");
    gear.stop();
  }

  public void dark(SensorPort port, int level)
  {
    System.out.println("Evt: dark(" + level + ")");
  }

  public void pressed(SensorPort port)
  {
    System.out.println("Evt: pressed()");
    gear.forward();
  }

  public void released(SensorPort port)
  {
    System.out.println("Evt: released()");
  }

  public static void main(String[] args)
  {
    new MultiSensor();
  }
}
