// RFIDEx3.java
// Event detection of RFID sensor

import ch.aplu.nxt.*;
import lejos.nxt.Button;
import lejos.nxt.ButtonListener;

public class RFIDEx3 implements RFIDListener, ButtonListener
{
  private TurtleRobot robot = new TurtleRobot();
  private final long friendId = 38726991952L;  // Adapt to your transponder
  private volatile boolean isStandby = true ;
  private volatile boolean isQuitting = false;

  public RFIDEx3()
  {
    RFIDSensor rfid = new RFIDSensor(SensorPort.S1);
    robot.addPart(rfid);
    rfid.addRFIDListener(this);
    Button.ESCAPE.addButtonListener(this);
    while (!isQuitting)
    {
      System.out.println("Wait friend ID..");
      System.out.println("ESC to stop");
      while (isStandby)
        Tools.delay(100);
      if (isQuitting)
        continue;
      robot.forward(100);
      robot.left(90);
      isStandby = true;
    }
    robot.exit();
  }

  public void detected(SensorPort port, long id)
  {
    if (id == friendId)
    {
      System.out.println("Identified!");
      robot.playTone(2000, 100);
      isStandby = false;
    }
  }

  public void buttonPressed(Button b)
  {
    isStandby = false;
    isQuitting = true;
  }

  public void buttonReleased(Button b)
  {
  }

  public static void main(String[] args)
  {
    new RFIDEx3();
  }
}
