// SlaveRobot.java
// Receive commands from MasterRobot

import ch.aplu.nxt.*;
import lejos.nxt.*;

public class SlaveRobot
  implements TransceiverListener
{
  private interface Command
  {
    int FORWARD  = 1;
    int BACKWARD = 2;
    int LEFT     = 3;
    int RIGHT    = 4;
    int STOP     = 5;
    int SETSPEED = 6;
  }

  private final String recipient = "NXT";
  private Gear gear;
  private Transceiver tr;

  public SlaveRobot()
  {
    NxtRobot robot = new NxtRobot();

    gear = new Gear();
    robot.addPart(gear);
    gear.setSpeed(30);

    tr = new Transceiver(recipient);
    tr.addTransceiverListener(this);
    robot.addPart(tr);

    tr.switchOn(); // Blocks until connected

    Tools.putSleep();  // Wait for termination
    robot.exit();
  }

  public void received(int state, int value)
  {
    switch (state)
    {
      case Command.FORWARD:
        gear.forward();
        break;

      case Command.BACKWARD:
        gear.backward();
        break;

      case Command.LEFT:
        gear.left();
        break;

      case Command.RIGHT:
        gear.right();
        break;

      case Command.STOP:
        gear.stop();
        break;

      case Command.SETSPEED:
        gear.setSpeed(value);
        break;
    }
  }

  public void notifyConnection(boolean connected)
  {
    if (!connected)
      Tools.wakeUp();  // Terminate program
  }

  public void isListening()
  {}

  public static void main(String[] args)
  {
    new SlaveRobot();
  }
}
