// SuperProEx4.java
// Switches at pin B0, B1 control motors, analog input at A0 sets the speed

import ch.aplu.nxt.*;

public class SuperProEx4 implements PrototypeListener
{
  private SuperProSensor sps = new SuperProSensor();
  private Motor motA =  new Motor(MotorPort.A);
  private Motor motB =  new Motor(MotorPort.B);

  public SuperProEx4()
  {
    NxtRobot robot = new NxtRobot();
    robot.addPart(motA);
    robot.addPart(motB);
    robot.addPart(sps);
    sps.addPrototypeListener(this);
    int[] ain = new int[4];
    int[] din = new int[8];
    sps.read(ain, din);
    setSpeed(ain[0]);
    if (din[0] == 1)
      motA.forward();
    if (din[1] == 1)
      motB.forward();
    Tools.waitEscape("ESCAPE to quit");
    robot.exit();
  }

  private void setSpeed(int s)
  {
    motA.setSpeed(s * 100 / 1023);
    if (motA.isMoving())
      motA.forward();
    motB.setSpeed(s * 100 / 1023);
    if (motB.isMoving())
      motB.forward();
  }

  public void ainChanged(SensorPort port, int[] ain)
  {
    if (ain[0] != -1)
    {
      System.out.println("" + ain[0]);
      setSpeed(ain[0]);
    }
  }

  public void dinChanged(SensorPort port, int[] din)
  {
    if (din[0] == 0)
      motA.stop();
    if (din[0] == 1)
      motA.forward();
    if (din[1] == 0)
      motB.stop();
    if (din[1] == 1)
      motB.forward();
  }

  public static void main(String[] args)
  {
    new SuperProEx4();
  }
}
