// SuperProMorse.java
// The Morse code consists of dots (short beeps called dits) and dashes
// (longer beeps called dashs.) The dash is 3 times longer than the dot and there is
// a pause lasting the same time as one dot between beeps in the character and
// a pause lasting as one dash between characters. The pause between words should last 7 dots.

import ch.aplu.nxt.*;
import java.util.*;

public class SuperProMorse
{
  private Hashtable<Character, String> code = new Hashtable<Character, String>();
  private final int dot = 60; // ms
  private SuperProSensor sps = new SuperProSensor(SensorPort.S1);


  public SuperProMorse()
  {
    NxtRobot robot = new NxtRobot();
    robot.addPart(sps);
    populateCode();
  //  play("abcdefghijklmnopqrstuvwxyz1234567890");
    play("cq cq de hb9abh cq cq de hb9abh pse k");
    robot.exit();
  }

  void play(String s)
  {
    for (int i = 0; i < s.length(); i++)
    {
      char ch = s.charAt(i);
      System.out.print(ch);
      String pattern = code.get(ch);
      playPattern(pattern);
    }
  }

  void populateCode()
  {
    code.put(' ', " ");
    code.put('a', ".-");
    code.put('b', "-...");
    code.put('c', "-.-.");
    code.put('d', "-..");
    code.put('e', ".");
    code.put('f', "..-.");
    code.put('g', "--.");
    code.put('h', "....");
    code.put('i', "..");
    code.put('j', ".---");
    code.put('k', "-.-");
    code.put('l', ".-..");
    code.put('m', "--");
    code.put('n', "-.");
    code.put('o', "---");
    code.put('p', ".--.");
    code.put('q', "--.-");
    code.put('r', ".-.");
    code.put('s', "...");
    code.put('t', "-");
    code.put('u', "..-");
    code.put('v', "...-");
    code.put('w', ".--");
    code.put('x', "-..-");
    code.put('y', "-.--");
    code.put('z', "--..");
    code.put('1', ".----");
    code.put('2', "..---");
    code.put('3', "...--");
    code.put('4', "....-");
    code.put('5', ".....");
    code.put('6', "-....");
    code.put('7', "--...");
    code.put('8', "---..");
    code.put('9', "----.");
    code.put('0', "-----");
  }

  void playPattern(String pattern)
  {
    if (pattern.equals(" "))
    {
      wordPause();
      return;
    }
    for (int i = 0; i < pattern.length(); i++)
    {
      char ch = pattern.charAt(i);
      if (ch == '.')
        dit();
      if (ch == '-')
        dah();
    }
    charPause();
  }

  void dit()
  {
    sps.setAnalogOut(0, 3, 1000, 1023);
    Tools.delay(dot);
    sps.setAnalogOut(0, 3, 1000, 0);
    Tools.delay(dot);
  }

  void dah()
  {
    sps.setAnalogOut(0, 3, 1000, 1023);
    Tools.delay(3 * dot);
    sps.setAnalogOut(0, 3, 1000, 0);
    Tools.delay(dot);
  }

  void charPause()
  {
    Tools.delay(3 * dot);
  }

  void wordPause()
  {
    Tools.delay(7 * dot);
  }

  public static void main(String[] args)
  {
    new SuperProMorse();
  }
}
