// SynchEx4.java
// Synchronization with wait/notify
// Race condition:
//  1. one thread checks inCallback -> false
//  2. Thread switch
//  3. the other thread checks inCallback -> still false
//  4. Both threads assume that inCallback is false -> error

import ch.aplu.nxt.*;
import lejos.nxt.Button;

public class SynchEx4 implements SoundListener, UltrasonicListener
{
  private TurtleRobot t = new TurtleRobot();
  private volatile boolean inCallback = false;

  public SynchEx4()
  {
    SoundSensor ss = new SoundSensor(SensorPort.S1);
    t.addPart(ss);
    ss.addSoundListener(this, 40);

    UltrasonicSensor us = new UltrasonicSensor(SensorPort.S2);
    t.addPart(us);
    us.addUltrasonicListener(this, 40);

    while (!Button.ESCAPE.isPressed())
    {}

    t.exit();
  }

  public void loud(SensorPort port, int level)
  {
    if (inCallback)
      putSleep();
    inCallback = true;
    t.backward(40);
    t.right(90);
    inCallback = false;
    wakeUp();
  }

  public void quiet(SensorPort port, int level)
  {}

  public void far(SensorPort port, int level)
  {}

  public  void near(SensorPort port, int level)
  {
    if (inCallback)
      putSleep();
    inCallback = true;
    t.left(90);
    t.forward(10);
    inCallback = false;
    wakeUp();
  }

  private void putSleep()
  {
    synchronized(this)
    {
      try
      {
        wait();
      }
      catch (InterruptedException ex)
      {}
    }
  }

  private void wakeUp()
  {
    synchronized(this)
    {
      notify();
    }
  }

  public static void main(String[] args)
  {
    new SynchEx4();
  }
}
