// TempReg.java
// PrototypeSensor at port S1 (heater at B0)
// Temperature sensor at port S2, treated as LightSensor

import ch.aplu.nxt.*;
import lejos.nxt.Button;
import lejos.nxt.ButtonListener;

class TemperatureSensor extends LightSensor
{
  public TemperatureSensor(SensorPort port)
  {
    super(port);
  }
}

public class TempReg implements ButtonListener
{
  private volatile boolean isRunning = true;
  private final int out = 1;
  private final int sollWert = 600;
  private final int hysteresis = 3;

  public TempReg()
  {
    NxtRobot robot = new NxtRobot();
    Button.ESCAPE.addButtonListener(this);
    System.out.println("ESCAPE to quit");
    PrototypeSensor ps = new PrototypeSensor(SensorPort.S1);
    robot.addPart(ps);
    TemperatureSensor ts =  new TemperatureSensor(SensorPort.S2);
    robot.addPart(ts);
    int[] ioControl = {out, out, out, out, out, out};
    ps.setDIO(ioControl);
    while (isRunning)
    {
      int isWert = ts.getValue();
      System.out.println("v: " + isWert);
      if (isWert > sollWert + hysteresis)
        turnOff(ps);
      if (isWert < sollWert - hysteresis)
        turnOn(ps);
    }
    robot.exit();
  }

  private void turnOn(PrototypeSensor ps)
  {
     int[] dout = new int[6];
     dout[0] = 1;
     ps.write(dout);
  }

  private void turnOff(PrototypeSensor ps)
  {
     int[] dout = new int[6];
     dout[0] = 0;
     ps.write(dout);
  }

  public void buttonPressed(Button b)
  {
    isRunning = false;
  }

  public void buttonReleased(Button b)
  {
  }

  public static void main(String[] args)
  {
    new TempReg();
  }
}
